#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Setup file for Pequod
"""

import os
import sys
import inspect
from distutils.cmd import Command

import setuptools
from setuptools.command.test import test as TestCommand
from setuptools import setup

__location__ = os.path.join(os.getcwd(), os.path.dirname(inspect.getfile(inspect.currentframe())))

# Change these settings according to your needs
MAIN_PACKAGE = 'pequod'
VERSION = '0.4'
DESCRIPTION = 'Pequod Cloud Solution meta package'
LICENSE = 'Apache License 2.0'
URL = 'http://pequod.zone/'
AUTHOR = 'Henning Jacobs'
EMAIL = 'henning.jacobs@zalando.de'

# Add here all kinds of additional classifiers as defined under
# https://pypi.python.org/pypi?%3Aaction=list_classifiers
CLASSIFIERS = [
    'Development Status :: 4 - Beta',
    'Programming Language :: Python',
    'Operating System :: POSIX :: Linux',
    'License :: OSI Approved :: Apache Software License'
]

KEYWORDS = 'pequod cloud paas docker container'

# Add here console scripts like ['hello_world = pequod_agent.module:function']
CONSOLE_SCRIPTS = []




def get_install_requirements(path):
    content = open(os.path.join(__location__, path)).read()
    return [req for req in content.split('\\n') if req != '']


def read(fname):
    return open(os.path.join(__location__, fname)).read()


def setup_package():
    # Assemble additional setup commands
    cmdclass = {}

    install_reqs = get_install_requirements('requirements.txt')

    command_options = {}

    setup(
        name=MAIN_PACKAGE,
        version=VERSION,
        url=URL,
        description=DESCRIPTION,
        author=AUTHOR,
        author_email=EMAIL,
        license=LICENSE,
        long_description=read('README.rst'),
        classifiers=CLASSIFIERS,
        keywords=KEYWORDS,
        test_suite='tests',
        packages=setuptools.find_packages(exclude=['tests', 'tests.*']),
        install_requires=install_reqs,
        setup_requires=['six'],
        cmdclass=cmdclass,
        tests_require=['pytest-cov', 'pytest'],
        command_options=command_options,
        entry_points={'console_scripts': CONSOLE_SCRIPTS},
    )


if __name__ == '__main__':
    setup_package()
